@@ -31,7 +31,7 @@ class AnyTitleAdapter(object) :
         
     @property
     def title(self) :
-        for adapter in sorted (subscribers([self.context], IAnyTitle)) :
+        for adapter in sorted (subscribers([self.context], IAnyTitle), reverse=True) :
             title = adapter.title
             if title is not None :
                 title = title.strip()
@@ -42,7 +42,7 @@ class AnyTitleAdapter(object) :
     @property
     def shorttitle(self) :
 
-        titles = ( y for y in ( x.title.strip() for x in subscribers([self.context], IAnyTitle) ) if y )
+        titles = ( y for y in ( x.title.strip() for x in subscribers([self.context], IAnyTitle)) if y )
         
         try :
             title = titles.next()
