@@ -13,10 +13,10 @@ __version__ = "$Revision: 12897 $"
 from zope.component import adapts
 from zope.annotation.interfaces import IAttributeAnnotatable
 from zope.dublincore.interfaces import IZopeDublinCore
-from anytitlesubscriberbase import AnyTitileSubscriberBase
+from anytitlesubscriberbase import AnyTitleSubscriberBase
 
 
-class ZDC2TitleSubscribe( AnyTitileSubscriberBase ) :
+class ZDC2TitleSubscribe( AnyTitleSubscriberBase ) :
     order = 1
     adapts(IAttributeAnnotatable)
     
