@@ -1,10 +1,10 @@
 ### -*- coding: utf-8 -*- #############################################
 #######################################################################
-"""Product class for the Zope 3 based product package
+"""Any2PathAdapter class for the Zope 3 based ng.adapter.path package
 
 $Id: product.py 12897 2007-11-10 15:32:08Z cray $
 """
-__author__  = "Yegor Shershnev"
+__author__  = "Yegor Shershnev, 2007"
 __license__ = "GPL"
 __version__ = "$Revision: 12897 $"
 
@@ -25,4 +25,4 @@ class Any2PathAdapter(PathAdapterBase) :
     name = ""
     
     def _tailpath(self,path) :
-        return path
\ No newline at end of file
+        return path
