@@ -2,11 +2,11 @@
 #######################################################################
 """Interfaces for the Zope 3 based ng.adapter.path package
 
-$Id: interfaces.py 49951 2008-02-06 20:16:04Z cray $
+$Id: interfaces.py 50637 2008-02-12 21:29:19Z cray $
 """
-__author__  = ""
+__author__  = "Yegor Shershnev, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49951 $"
+__version__ = "$Revision: 50637 $"
  
 from zope.interface import Interface
 
